package com.ruoyi.zongzhi.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.zongzhi.mapper.TcDtSxMapper;
import com.ruoyi.zongzhi.domain.TcDtSx;
import com.ruoyi.zongzhi.service.ITcDtSxService;

/**
 * 动态筛选Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-08-28
 */
@Service
public class TcDtSxServiceImpl implements ITcDtSxService 
{
    @Autowired
    private TcDtSxMapper tcDtSxMapper;

    /**
     * 查询动态筛选
     * 
     * @param id 动态筛选主键
     * @return 动态筛选
     */
    @Override
    public TcDtSx selectTcDtSxById(Long id)
    {
        return tcDtSxMapper.selectTcDtSxById(id);
    }

    /**
     * 查询动态筛选列表
     * 
     * @param tcDtSx 动态筛选
     * @return 动态筛选
     */
    @Override
    public List<TcDtSx> selectTcDtSxList(TcDtSx tcDtSx)
    {
        return tcDtSxMapper.selectTcDtSxList(tcDtSx);
    }

    /**
     * 新增动态筛选
     * 
     * @param tcDtSx 动态筛选
     * @return 结果
     */
    @Override
    public int insertTcDtSx(TcDtSx tcDtSx)
    {
        return tcDtSxMapper.insertTcDtSx(tcDtSx);
    }

    /**
     * 修改动态筛选
     * 
     * @param tcDtSx 动态筛选
     * @return 结果
     */
    @Override
    public int updateTcDtSx(TcDtSx tcDtSx)
    {
        return tcDtSxMapper.updateTcDtSx(tcDtSx);
    }

    /**
     * 批量删除动态筛选
     * 
     * @param ids 需要删除的动态筛选主键
     * @return 结果
     */
    @Override
    public int deleteTcDtSxByIds(Long[] ids)
    {
        return tcDtSxMapper.deleteTcDtSxByIds(ids);
    }

    /**
     * 删除动态筛选信息
     * 
     * @param id 动态筛选主键
     * @return 结果
     */
    @Override
    public int deleteTcDtSxById(Long id)
    {
        return tcDtSxMapper.deleteTcDtSxById(id);
    }
}
